==> AsposeCellsCloud-CellsApi-24.3.tar.gz: AsposeCellsCloud-CellsApi-24.3/lib/AsposeCellsCloud/Object/LoadOptions.pm <==
=begin comment

Copyright (c) 2024 Aspose.Cells Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

=end comment

=cut

package AsposeCellsCloud::Object::LoadOptions;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;
 


use base ("Class::Accessor", "Class::Data::Inheritable");



__PACKAGE__->mk_classdata('attribute_map' => {});
__PACKAGE__->mk_classdata('swagger_types' => {});
__PACKAGE__->mk_classdata('method_documentation' => {}); 
__PACKAGE__->mk_classdata('class_documentation' => {});

# new object
sub new { 
    my ($class, %args) = @_; 

	my $self = bless {}, $class;

	foreach my $attribute (keys %{$class->attribute_map}) {
		my $args_key = $class->attribute_map->{$attribute};
		$self->$attribute( $args{ $args_key } );
	}

	return $self;
}  

# return perl hash
sub to_hash {
    return decode_json(JSON->new->convert_blessed->encode( shift ));
}

# used by JSON for serialization
sub TO_JSON { 
    my $self = shift;
    my $_data = {};
    foreach my $_key (keys %{$self->attribute_map}) {
        if (defined $self->{$_key}) {
            $_data->{$self->attribute_map->{$_key}} = $self->{$_key};
        }
    }
    return $_data;
}

# from Perl hashref
sub from_hash {
    my ($self, $hash) = @_;

    # loop through attributes and use swagger_types to deserialize the data
    while ( my ($_key, $_type) = each %{$self->swagger_types} ) {
    	my $_json_attribute = $self->attribute_map->{$_key}; 
        if ($_type =~ /^array\[/i) { # array
            my $_subclass = substr($_type, 6, -1);
            my @_array = ();
            foreach my $_element (@{$hash->{$_json_attribute}}) {
                push @_array, $self->_deserialize($_subclass, $_element);
            }
            $self->{$_key} = \@_array;
        } elsif (exists $hash->{$_json_attribute}) { #hash(model), primitive, datetime
            $self->{$_key} = $self->_deserialize($_type, $hash->{$_json_attribute});
        } else {
        	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
        }
    }

    return $self;
}

# deserialize non-array data
sub _deserialize {
    my ($self, $type, $data) = @_;
    $log->debugf("deserializing %s with %s",Dumper($data), $type);

    if ($type eq 'DateTime') {
        return DateTime->from_epoch(epoch => str2time($data));
    } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
        return $data;
    } else { # hash(model)
        my $_instance = eval "AsposeCellsCloud::Object::$type->new()";
        return $_instance->from_hash($data);
    }
}


__PACKAGE__->class_documentation({description => '',
                                  class => 'LoadOptions',
                                  required => [], # TODO
}                                 );


__PACKAGE__->method_documentation({
     'convert_numeric_data' => {
     	datatype => 'string',
     	base_name => 'ConvertNumericData',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'interrupt_monitor' => {
     	datatype => 'string',
     	base_name => 'InterruptMonitor',
     	description => 'Gets and sets the interrupt monitor.',
     	format => '',
     	read_only => '',
     		},
     'language_code' => {
     	datatype => 'string',
     	base_name => 'LanguageCode',
     	description => 'Gets or sets the user interface language of the Workbook version based on CountryCode that has saved the file.',
     	format => '',
     	read_only => '',
     		},
     'load_data_options' => {
     	datatype => 'string',
     	base_name => 'LoadDataOptions',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'load_format' => {
     	datatype => 'string',
     	base_name => 'LoadFormat',
     	description => 'Gets the load format.',
     	format => '',
     	read_only => '',
     		},
     'only_load_document_properties' => {
     	datatype => 'string',
     	base_name => 'OnlyLoadDocumentProperties',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'parsing_formula_on_open' => {
     	datatype => 'string',
     	base_name => 'ParsingFormulaOnOpen',
     	description => 'Indicates whether parsing the formula when reading the file.',
     	format => '',
     	read_only => '',
     		},
     'password' => {
     	datatype => 'string',
     	base_name => 'Password',
     	description => 'Gets and set the password of the workbook.',
     	format => '',
     	read_only => '',
     		},
     'region' => {
     	datatype => 'string',
     	base_name => 'Region',
     	description => 'Gets or sets the system regional settings based on CountryCode at the time the file was loaded.',
     	format => '',
     	read_only => '',
     		},
     'standard_font' => {
     	datatype => 'string',
     	base_name => 'StandardFont',
     	description => 'Sets the default standard font name',
     	format => '',
     	read_only => '',
     		},
     'standard_font_size' => {
     	datatype => 'double',
     	base_name => 'StandardFontSize',
     	description => 'Sets the default standard font size.',
     	format => '',
     	read_only => '',
     		},    
});

__PACKAGE__->swagger_types( {
    'convert_numeric_data' => 'string',
    'interrupt_monitor' => 'string',
    'language_code' => 'string',
    'load_data_options' => 'string',
    'load_format' => 'string',
    'only_load_document_properties' => 'string',
    'parsing_formula_on_open' => 'string',
    'password' => 'string',
    'region' => 'string',
    'standard_font' => 'string',
    'standard_font_size' => 'double' 
} );

__PACKAGE__->attribute_map( {
    'convert_numeric_data' => 'ConvertNumericData',
    'interrupt_monitor' => 'InterruptMonitor',
    'language_code' => 'LanguageCode',
    'load_data_options' => 'LoadDataOptions',
    'load_format' => 'LoadFormat',
    'only_load_document_properties' => 'OnlyLoadDocumentProperties',
    'parsing_formula_on_open' => 'ParsingFormulaOnOpen',
    'password' => 'Password',
    'region' => 'Region',
    'standard_font' => 'StandardFont',
    'standard_font_size' => 'StandardFontSize' 
} );

__PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});


1;

==> AsposeCellsCloud-CellsApi-24.7.tar.gz: AsposeCellsCloud-CellsApi-24.7/lib/AsposeCellsCloud/Object/LoadOptions.pm <==
=begin comment

Copyright (c) 2024 Aspose.Cells Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all 
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

=end comment

=cut

package AsposeCellsCloud::Object::LoadOptions;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;
 


use base ("Class::Accessor", "Class::Data::Inheritable");



__PACKAGE__->mk_classdata('attribute_map' => {});
__PACKAGE__->mk_classdata('swagger_types' => {});
__PACKAGE__->mk_classdata('method_documentation' => {}); 
__PACKAGE__->mk_classdata('class_documentation' => {});

# new object
sub new { 
    my ($class, %args) = @_; 

	my $self = bless {}, $class;

	foreach my $attribute (keys %{$class->attribute_map}) {
		my $args_key = $class->attribute_map->{$attribute};
		$self->$attribute( $args{ $args_key } );
	}

	return $self;
}  

# return perl hash
sub to_hash {
    return decode_json(JSON->new->convert_blessed->encode( shift ));
}

# used by JSON for serialization
sub TO_JSON { 
    my $self = shift;
    my $_data = {};
    foreach my $_key (keys %{$self->attribute_map}) {
        if (defined $self->{$_key}) {
            $_data->{$self->attribute_map->{$_key}} = $self->{$_key};
        }
    }
    return $_data;
}

# from Perl hashref
sub from_hash {
    my ($self, $hash) = @_;

    # loop through attributes and use swagger_types to deserialize the data
    while ( my ($_key, $_type) = each %{$self->swagger_types} ) {
    	my $_json_attribute = $self->attribute_map->{$_key}; 
        if ($_type =~ /^array\[/i) { # array
            my $_subclass = substr($_type, 6, -1);
            my @_array = ();
            foreach my $_element (@{$hash->{$_json_attribute}}) {
                push @_array, $self->_deserialize($_subclass, $_element);
            }
            $self->{$_key} = \@_array;
        } elsif (exists $hash->{$_json_attribute}) { #hash(model), primitive, datetime
            $self->{$_key} = $self->_deserialize($_type, $hash->{$_json_attribute});
        } else {
        	$log->debugf("Warning: %s (%s) does not exist in input hash\n", $_key, $_json_attribute);
        }
    }

    return $self;
}

# deserialize non-array data
sub _deserialize {
    my ($self, $type, $data) = @_;
    $log->debugf("deserializing %s with %s",Dumper($data), $type);

    if ($type eq 'DateTime') {
        return DateTime->from_epoch(epoch => str2time($data));
    } elsif ( grep( /^$type$/, ('int', 'double', 'string', 'boolean'))) {
        return $data;
    } else { # hash(model)
        my $_instance = eval "AsposeCellsCloud::Object::$type->new()";
        return $_instance->from_hash($data);
    }
}


__PACKAGE__->class_documentation({description => 'Represents the options of loading the file.',
                                  class => 'LoadOptions',
                                  required => [], # TODO
}                                 );


__PACKAGE__->method_documentation({
     'convert_numeric_data' => {
     	datatype => 'string',
     	base_name => 'ConvertNumericData',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'interrupt_monitor' => {
     	datatype => 'string',
     	base_name => 'InterruptMonitor',
     	description => 'Gets and sets the interrupt monitor.',
     	format => '',
     	read_only => '',
     		},
     'language_code' => {
     	datatype => 'string',
     	base_name => 'LanguageCode',
     	description => 'Gets or sets the user interface language of the Workbook version based on CountryCode that has saved the file.',
     	format => '',
     	read_only => '',
     		},
     'load_data_options' => {
     	datatype => 'string',
     	base_name => 'LoadDataOptions',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'load_format' => {
     	datatype => 'string',
     	base_name => 'LoadFormat',
     	description => 'Gets the load format.',
     	format => '',
     	read_only => '',
     		},
     'only_load_document_properties' => {
     	datatype => 'string',
     	base_name => 'OnlyLoadDocumentProperties',
     	description => '',
     	format => '',
     	read_only => '',
     		},
     'parsing_formula_on_open' => {
     	datatype => 'string',
     	base_name => 'ParsingFormulaOnOpen',
     	description => 'Indicates whether parsing the formula when reading the file.',
     	format => '',
     	read_only => '',
     		},
     'password' => {
     	datatype => 'string',
     	base_name => 'Password',
     	description => 'Gets and set the password of the workbook.',
     	format => '',
     	read_only => '',
     		},
     'region' => {
     	datatype => 'string',
     	base_name => 'Region',
     	description => 'Gets or sets the system regional settings based on CountryCode at the time the file was loaded.',
     	format => '',
     	read_only => '',
     		},
     'standard_font' => {
     	datatype => 'string',
     	base_name => 'StandardFont',
     	description => 'Sets the default standard font name',
     	format => '',
     	read_only => '',
     		},
     'standard_font_size' => {
     	datatype => 'double',
     	base_name => 'StandardFontSize',
     	description => 'Sets the default standard font size.',
     	format => '',
     	read_only => '',
     		},    
});

__PACKAGE__->swagger_types( {
    'convert_numeric_data' => 'string',
    'interrupt_monitor' => 'string',
    'language_code' => 'string',
    'load_data_options' => 'string',
    'load_format' => 'string',
    'only_load_document_properties' => 'string',
    'parsing_formula_on_open' => 'string',
    'password' => 'string',
    'region' => 'string',
    'standard_font' => 'string',
    'standard_font_size' => 'double' 
} );

__PACKAGE__->attribute_map( {
    'convert_numeric_data' => 'ConvertNumericData',
    'interrupt_monitor' => 'InterruptMonitor',
    'language_code' => 'LanguageCode',
    'load_data_options' => 'LoadDataOptions',
    'load_format' => 'LoadFormat',
    'only_load_document_properties' => 'OnlyLoadDocumentProperties',
    'parsing_formula_on_open' => 'ParsingFormulaOnOpen',
    'password' => 'Password',
    'region' => 'Region',
    'standard_font' => 'StandardFont',
    'standard_font_size' => 'StandardFontSize' 
} );

__PACKAGE__->mk_accessors(keys %{__PACKAGE__->attribute_map});


1;
